wsgi-oauth2
===========

.. image:: http://oauth.net/images/oauth-2-sm.png

This module provides a simple WSGI middleware that requires the user to
authenticate via the specific `OAuth 2.0`_ service e.g. Facebook_, Google_.

You can install the package via downloading from PyPI_::

    $ easy_install wsgi-oauth2

Read the documentation_ as well.

.. _OAuth 2.0: http://oauth.net/2/
.. _Facebook: http://www.facebook.com/
.. _Google: http://www.google.com/
.. _PyPI: http://pypi.python.org/pypi/wsgi-oauth2
.. _documentation: http://styleshare.github.com/wsgi-oauth2/

